.. _index:

.. include:: ./../README.rst

Users Guide
-----------

**Installation:**

.. toctree::
   :maxdepth: 1

   installation
   installation_win
   setup
   upgrade

**Usage**

.. toctree::
   :maxdepth: 1

   usage/general
   usage/git_support
   usage/performance
   usage/locking
   usage/statistics
   usage/backup
   usage/subrepos
   usage/debugging
   usage/troubleshooting

**Develop**

.. toctree::
   :maxdepth: 1

   contributing
   changelog

**API**

.. toctree::
   :maxdepth: 1

   api/api
   api/models


Other topics
------------

* :ref:`genindex`
* :ref:`search`

.. _virtualenv: http://pypi.python.org/pypi/virtualenv
.. _python: http://www.python.org/
.. _django: http://www.djangoproject.com/
.. _mercurial: http://mercurial.selenic.com/
.. _bitbucket: http://bitbucket.org/
.. _subversion: http://subversion.tigris.org/
.. _git: http://git-scm.com/
.. _celery: http://celeryproject.org/
.. _Sphinx: http://sphinx.pocoo.org/
.. _vcs: http://pypi.python.org/pypi/vcs
